Source code rewriting for snap! inline snapshots in ClojureScript.
Uses rewrite-clj (which supports ClojureScript) for AST manipulation and still.node-io for Node.js file I/O.
Source code rewriting for snap! inline snapshots in ClojureScript. Uses rewrite-clj (which supports ClojureScript) for AST manipulation and still.node-io for Node.js file I/O.
(add-expected-value! file-path line expected-value)Add or update the expected value in a snap! call.
Arguments:
Returns a map with :status (:inserted, :updated, :not-found, :error).
Add or update the expected value in a snap! call. Arguments: - file-path: Absolute path to the source file - line: Line number of the snap! call (compile-time, pre-edit) - expected-value: The serialised value to insert as expected Returns a map with :status (:inserted, :updated, :not-found, :error).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |